@@ -33,14 +33,15 @@ np_array = progress.to_numpy()
 
 # %%
 
-progress = ProgressTable(columns=["step", "x", "x squared"], num_decimal_places=10)
+progress = ProgressTable(columns=["step", "x", "x squared"], num_decimal_places=10,
+                         embedded_progress_bar=True)
 progress.add_column("x root", color=Fore.RED, width=12)
 
 for step in progress(range(3)):
     progress["step"] = step  # insert step value in the current row
 
     for _ in range(10):  # display progress bar
-        progress["x"] = 1
+        progress["x"] = _
         time.sleep(0.1)  # simulate artificial work
 
     x = random.randint(0, 200)
